import email
from setuptools import setup

setup(
    name='primosa02',
    version='0.0.1',
    description='Calculate prime numbers',
)

setup(classifiers=["Programming Language :: Python :: 3 :: Only",
"License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
"Operating System :: OS Independent",],)

setup(install_requires=["rpy2",],)

setup(url="https://github.com/OscarVC2/primos",
author="Oscar Valladares",
author_email="oscarvc.2@gmail.com",)